@@ -13,15 +13,16 @@ Class::Debug - Add Runtime Debugging to a Class
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
-=head1 SUBROUTINES/METHODS
+=head1 SYNOPSIS
 
-=head2 setup
+The C<Class::Debug> module is a lightweight utility designed to inject runtime debugging capabilities into other classes,
+primarily by layering configuration and logging support.
 
 Add this to your constructor:
 
@@ -32,11 +33,31 @@ Add this to your constructor:
    	my $class = shift;
 	my $params = Params::Get(undef, \@_);
 
-	$params = Class::Debug::setup($params);
+	$params = Class::Debug::setup($class, $params);
 
 	return bless $params, $class;
     }
 
+=head1 SUBROUTINES/METHODS
+
+=head2 setup
+
+Configure your class for runtime debugging.
+
+Takes two arguments:
+
+=over 4
+
+=item * C<class>
+
+=item * C<params>
+
+A hashref containing default parameters to be used in the constructor.
+
+=back
+
+Returns the new values for the constructor.
+
 Now you can set up a configuration file and environment variables to debug your module.
 
 =cut
@@ -73,6 +94,8 @@ sub setup
 	} else {
 		$params->{'logger'} = Log::Abstraction->new(carp_on_warn => 1);
 	}
+
+	return $params;
 }
 
 =head1 SEE ALSO
